*************
API reference
*************

..
  .. autosummary::
     :toctree: api
     :recursive:

     glooey.widget
     glooey.root
     glooey.containers
     glooey.buttons
     glooey.images
     glooey.text
     glooey.scrolling
     glooey.dialogs
     glooey.misc
     glooey.drawing
     glooey.helpers
     glooey.themes
